  ```python3
  from sogoqa import qa 
  answer = qa.ask("刘德华是谁")
  print(answer)
  '刘德华（Andy Lau，1961年9月27日-），影视男演员、歌手、作词人、制片人，出生于中国香港，是中国香港乐坛“四大天王”之一。他曾三次获香港电影金像奖最佳男主角、二次金马奖最佳男主角荣誉，已参演超过140部电影。同时，作为歌手的他六次获得十大劲歌金曲最受欢迎男歌星奖（截至2004年），并被《吉尼斯世界纪录大全》评为“获奖最多的香港男歌手”。'

  ```
